from dotenv import load_dotenv

# Keep this in sync with pyproject.toml manually
# Or use this https://github.com/tiangolo/poetry-version-plugin
# after this is resolved: https://github.com/tiangolo/poetry-version-plugin/issues/27
__version__ = "0.4.1"

load_dotenv()
